@@ -16,22 +16,22 @@ from datetime import datetime
 from typing import Dict, List
 
 from .literals import (
-    ActivityType,
-    CommentStatusType,
-    CommentVisibilityType,
-    DocumentSourceType,
-    DocumentStatusType,
-    DocumentThumbnailType,
-    LocaleType,
-    PrincipalType,
-    ResourceStateType,
-    ResourceType,
-    RolePermissionType,
-    RoleType,
-    ShareStatusType,
-    StorageType,
-    UserStatusType,
-    UserType,
+    ActivityTypeType,
+    CommentStatusTypeType,
+    CommentVisibilityTypeType,
+    DocumentSourceTypeType,
+    DocumentStatusTypeType,
+    DocumentThumbnailTypeType,
+    LocaleTypeType,
+    PrincipalTypeType,
+    ResourceStateTypeType,
+    ResourceTypeType,
+    RolePermissionTypeType,
+    RoleTypeType,
+    ShareStatusTypeType,
+    StorageTypeType,
+    UserStatusTypeType,
+    UserTypeType,
 )
 
 if sys.version_info >= (3, 8):
@@ -105,7 +105,7 @@ ActivateUserResponseTypeDef = TypedDict(
 ActivityTypeDef = TypedDict(
     "ActivityTypeDef",
     {
-        "Type": ActivityType,
+        "Type": ActivityTypeType,
         "TimeStamp": datetime,
         "IsIndirectActivity": bool,
         "OrganizationId": str,
@@ -132,7 +132,7 @@ CommentMetadataTypeDef = TypedDict(
         "CommentId": str,
         "Contributor": "UserTypeDef",
         "CreatedTimestamp": datetime,
-        "CommentStatus": CommentStatusType,
+        "CommentStatus": CommentStatusTypeType,
         "RecipientId": str,
     },
     total=False,
@@ -152,8 +152,8 @@ _OptionalCommentTypeDef = TypedDict(
         "Text": str,
         "Contributor": "UserTypeDef",
         "CreatedTimestamp": datetime,
-        "Status": CommentStatusType,
-        "Visibility": CommentVisibilityType,
+        "Status": CommentStatusTypeType,
+        "Visibility": CommentVisibilityTypeType,
         "RecipientId": str,
     },
     total=False,
@@ -288,7 +288,7 @@ DocumentMetadataTypeDef = TypedDict(
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
         "LatestVersionMetadata": "DocumentVersionMetadataTypeDef",
-        "ResourceState": ResourceStateType,
+        "ResourceState": ResourceStateTypeType,
         "Labels": List[str],
     },
     total=False,
@@ -302,14 +302,14 @@ DocumentVersionMetadataTypeDef = TypedDict(
         "ContentType": str,
         "Size": int,
         "Signature": str,
-        "Status": DocumentStatusType,
+        "Status": DocumentStatusTypeType,
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
         "ContentCreatedTimestamp": datetime,
         "ContentModifiedTimestamp": datetime,
         "CreatorId": str,
-        "Thumbnail": Dict[DocumentThumbnailType, str],
-        "Source": Dict[DocumentSourceType, str],
+        "Thumbnail": Dict[DocumentThumbnailTypeType, str],
+        "Source": Dict[DocumentSourceTypeType, str],
     },
     total=False,
 )
@@ -323,7 +323,7 @@ FolderMetadataTypeDef = TypedDict(
         "ParentFolderId": str,
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
-        "ResourceState": ResourceStateType,
+        "ResourceState": ResourceStateTypeType,
         "Signature": str,
         "Labels": List[str],
         "Size": int,
@@ -442,8 +442,8 @@ ParticipantsTypeDef = TypedDict(
 PermissionInfoTypeDef = TypedDict(
     "PermissionInfoTypeDef",
     {
-        "Role": RoleType,
-        "Type": RolePermissionType,
+        "Role": RoleTypeType,
+        "Type": RolePermissionTypeType,
     },
     total=False,
 )
@@ -452,7 +452,7 @@ PrincipalTypeDef = TypedDict(
     "PrincipalTypeDef",
     {
         "Id": str,
-        "Type": PrincipalType,
+        "Type": PrincipalTypeType,
         "Roles": List["PermissionInfoTypeDef"],
     },
     total=False,
@@ -461,7 +461,7 @@ PrincipalTypeDef = TypedDict(
 ResourceMetadataTypeDef = TypedDict(
     "ResourceMetadataTypeDef",
     {
-        "Type": ResourceType,
+        "Type": ResourceTypeType,
         "Name": str,
         "OriginalName": str,
         "Id": str,
@@ -493,8 +493,8 @@ SharePrincipalTypeDef = TypedDict(
     "SharePrincipalTypeDef",
     {
         "Id": str,
-        "Type": PrincipalType,
-        "Role": RoleType,
+        "Type": PrincipalTypeType,
+        "Role": RoleTypeType,
     },
 )
 
@@ -503,8 +503,8 @@ ShareResultTypeDef = TypedDict(
     {
         "PrincipalId": str,
         "InviteePrincipalId": str,
-        "Role": RoleType,
-        "Status": ShareStatusType,
+        "Role": RoleTypeType,
+        "Status": ShareStatusTypeType,
         "ShareId": str,
         "StatusMessage": str,
     },
@@ -515,7 +515,7 @@ StorageRuleTypeTypeDef = TypedDict(
     "StorageRuleTypeTypeDef",
     {
         "StorageAllocatedInBytes": int,
-        "StorageType": StorageType,
+        "StorageType": StorageTypeType,
     },
     total=False,
 )
@@ -579,12 +579,12 @@ UserTypeDef = TypedDict(
         "OrganizationId": str,
         "RootFolderId": str,
         "RecycleBinFolderId": str,
-        "Status": UserStatusType,
-        "Type": UserType,
+        "Status": UserStatusTypeType,
+        "Type": UserTypeType,
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
         "TimeZoneId": str,
-        "Locale": LocaleType,
+        "Locale": LocaleTypeType,
         "Storage": "UserStorageMetadataTypeDef",
     },
     total=False,
